# NCUHEP

This project provides modules for the purpose of muography data reconstruction and simulation 

    ncuhep.muography.parser
    -parser

    ncuhep.muography.utils
    -cart2slope
    -cart2slope_vec
    -slope2cart
    -slope2cart_vec
    -det2earth
    -det2earth_vec
    -earth2det
    -earth2det_vec
    -zenith_azimuth_deg
    -zenith_azimuth_deg_vec
    -effective_area
    -solid_angle
    -array2combo
    -intercept_
    -multiple_intercept_
    -track_reconstruction
    -homogenous_generator
    -detection_simulation
    -run_homogenous_simulation
    -compute_basis

## Installation

```sh
pip install ncuhep